#!/bin/sh
# Add the LessTif stuff to host.def if it isn't already there:
if [ -r usr/X11R6/lib/X11/config/host.def ]; then
  if ! grep LessTif usr/X11R6/lib/X11/config/host.def 1> /dev/null 2> /dev/null ; then
    cat usr/X11R6/lib/X11/config/host.def-lesstif >> usr/X11R6/lib/X11/config/host.def
  fi
else
  cat usr/X11R6/lib/X11/config/host.def-lesstif >> usr/X11R6/lib/X11/config/host.def
fi
# Standard symlink creation section begins:
( cd usr/doc ; rm -rf lesstif-0.93.91 )
( cd usr/doc ; ln -sf /usr/X11R6/LessTif lesstif-0.93.91 )
( cd usr/X11R6/lib/X11 ; rm -rf mwm )
( cd usr/X11R6/lib/X11 ; ln -sf ../../../../etc/X11/mwm mwm )
( cd usr/X11R6/lib ; rm -rf libXm.so.2 )
( cd usr/X11R6/lib ; ln -sf libXm.so.2.0.1 libXm.so.2 )
( cd usr/X11R6/lib ; rm -rf libMrm.so.2 )
( cd usr/X11R6/lib ; ln -sf libMrm.so.2.0.1 libMrm.so.2 )
( cd usr/X11R6/lib ; rm -rf libDtPrint.so )
( cd usr/X11R6/lib ; ln -sf libDtPrint.so.1.0.0 libDtPrint.so )
( cd usr/X11R6/lib ; rm -rf libMrm.so )
( cd usr/X11R6/lib ; ln -sf libMrm.so.2.0.1 libMrm.so )
( cd usr/X11R6/lib ; rm -rf libUil.so.2 )
( cd usr/X11R6/lib ; ln -sf libUil.so.2.0.1 libUil.so.2 )
( cd usr/X11R6/lib ; rm -rf libUil.so )
( cd usr/X11R6/lib ; ln -sf libUil.so.2.0.1 libUil.so )
( cd usr/X11R6/lib ; rm -rf libXm.so )
( cd usr/X11R6/lib ; ln -sf libXm.so.2.0.1 libXm.so )
( cd usr/X11R6/lib ; rm -rf libDtPrint.so.1 )
( cd usr/X11R6/lib ; ln -sf libDtPrint.so.1.0.0 libDtPrint.so.1 )
( cd usr/X11R6/LessTif/doc ; rm -rf Lessdox )
( cd usr/X11R6/LessTif/doc ; ln -sf html Lessdox )
